#
# spec file for package ppc64-diag
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ppc64-diag
Version:        2.7.6
Release:        3.3.1
Summary:        Linux for Power Platform Diagnostics
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            http://sourceforge.net/projects/linux-diag/files/ppc64-diag
Source0:        http://downloads.sourceforge.net/project/linux-diag/ppc64-diag/v%{version}/%{name}-%{version}.tar.gz
#PATCH-FIX-OPENSUSE - ppc64-diag.varunused.patch - fix unused variables
Patch1:         ppc64-diag.varunused.patch
#PATCH-FIX-UPSTREAM - ppc64-diag-Drop-obsolete-logging-options-from-systemd-service-f.patch - fix systemd warning
Patch2:         ppc64-diag-Drop-obsolete-logging-options-from-systemd-service-f.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  cron
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  librtas-devel >= 1.4.0
BuildRequires:  libservicelog-devel
BuildRequires:  libtool
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libvpd-2)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(sqlite3)
Requires:       cron
# Light Path Diagnostics depends on below lsvpd version.
Requires:       lsvpd >= 1.7.1
Requires:       powerpc-utils >= 1.3.2
Requires:       servicelog
Requires(post): aaa_base
# autoselect the package on systems which have the /vdevice/IBM,sp node
# All pSeries POWER5 and later have this property
Supplements:    modalias(vio:TIBM*spS*)
ExclusiveArch:  ppc ppc64 ppc64le

%description
This package contains various diagnostic tools for PowerLinux.
These tools captures the diagnostic events from Power Systems
platform firmware, SES enclosures and device drivers, and
write events to servicelog database. It also provides automated
responses to urgent events such as environmental conditions and
predictive failures, if appropriate modifies the FRUs fault
indicator(s) and provides event notification to system
administrators or connected service frameworks.

%prep
%setup -q
%autopatch -p1

%build
sed -i 's@%{_prefix}/libexec/ppc64-diag@%{_libexecdir}@g' scripts/opal_errd.service
sed -i 's@%{_prefix}/libexec/ppc64-diag@%{_libexecdir}@g' scripts/rtas_errd.service
autoreconf -fvi
%configure
make %{?_smp_mflags}

%install
%make_install
chmod 644 %{buildroot}%{_sysconfdir}/ppc64-diag/servevent_parse.pl
mkdir %{buildroot}%{_sysconfdir}/ppc64-diag/ses_pages
ln -sf %{_sbindir}/usysattn %{buildroot}%{_sbindir}/usysfault
install -D -m0644 scripts/rtas_errd.service %{buildroot}%{_unitdir}/rtas_errd.service
install -D -m0644 scripts/opal_errd.service %{buildroot}%{_unitdir}/opal_errd.service
ln -s service %{buildroot}%{_sbindir}/rcrtas_errd
ln -s service %{buildroot}%{_sbindir}/rcopal_errd
rm %{buildroot}%{_prefix}/libexec/%{name}/opal_errd
rm %{buildroot}%{_prefix}/libexec/%{name}/rtas_errd
rm %{buildroot}%{_datadir}/doc/%{name}/COPYING
rm %{buildroot}%{_datadir}/doc/%{name}/README

%files
%license COPYING
%doc README
%{_sbindir}/*
%dir %{_sysconfdir}/ppc64-diag
%config %{_sysconfdir}/ppc64-diag/*
%config %{_sysconfdir}/rc.powerfail
%{_mandir}/man8/explain_syslog.8%{?ext_man}
%{_mandir}/man8/syslog_to_svclog.8%{?ext_man}
%{_mandir}/man8/diag_encl.8%{?ext_man}
%{_mandir}/man8/encl_led.8%{?ext_man}
%{_mandir}/man8/lp_diag.8%{?ext_man}
%{_mandir}/man8/usysattn.8%{?ext_man}
%{_mandir}/man8/usysfault.8%{?ext_man}
%{_mandir}/man8/usysident.8%{?ext_man}
%{_mandir}/man8/opal-dump-parse.8%{?ext_man}
%{_mandir}/man8/opal-elog-parse.8%{?ext_man}
%{_mandir}/man8/opal_errd.8%{?ext_man}
%attr(755,root,root) %{_sysconfdir}/cron.daily/run_diag_encl
%{_unitdir}/rtas_errd.service
%{_unitdir}/opal_errd.service

%post
%{_sysconfdir}/ppc64-diag/ppc64_diag_setup --register >/dev/null 2>&1
%{_sysconfdir}/ppc64-diag/lp_diag_setup --register >/dev/null 2>&1
%service_add_post rtas_errd.service
%service_add_post opal_errd.service

%preun
# Pre-uninstall script -------------------------------------------------
if [ "$1" = "0" ]; then # last uninstall
  %service_del_preun rtas_errd.service
  %service_del_preun opal_errd.service
  %{_sysconfdir}/ppc64-diag/ppc64_diag_setup --unregister >/dev/null
  %{_sysconfdir}/ppc64-diag/lp_diag_setup --unregister >/dev/null
fi

%triggerin -- librtas
# trigger on librtas upgrades ------------------------------------------
if [ "$2" = "2" ]; then
    systemctl restart rtas_errd.service >/dev/null
fi

%pre
%service_add_pre rtas_errd.service
%service_add_pre opal_errd.service

%postun
%service_del_postun rtas_errd.service
%service_del_postun opal_errd.service

%changelog
* Tue Mar 23 2021 msuchanek@suse.de
- Fix systemd warning about obsolete logging options (bsc#1183700 ltc#192095).
  + ppc64-diag-Drop-obsolete-logging-options-from-systemd-service-f.patch
* Thu Sep 19 2019 josef.moellers@suse.com
- Upgrade to v2.7.6
  - opal_errd: Enhance the purging logic of rotate_logs
  - diags/cronjob: Include disk diagnostics
  - CVE fixes
  [jsc#SLE-8324, CVE-2014-4039, CVE-2014-4038]
* Tue Apr 30 2019 josef.moellers@suse.com
- Upgrade to upstream version 2.7.5
  * Obsoletes 6 patches:
    + ppc64-diag.bug-1072708_fix_service_scripts.patch
    + ppc64-diag.bug-1072708_create_diag_disk_path.patch
    + ppc64-diag.bug-1072708_increase_buffer_for_vpd.patch
    + ppc64-diag.bug-1072708_remove_timestamp.patch
    + ppc64-diag.bug-1072708_create_diag_disk_log_directory.patch
    + bsc1113097-run_diag_encl-exit-gracefully.patch
  * rather that just fail, give more concise
    error messages in configure script
  * use bison rather than yacc
  * probe for indicators on running platform
  * usysattn, usysfault and usysident: add -P option to limit the
    operations to only the platform indicators excluding the
    enclosures.
  [jsc:SLE-6081]
* Tue Jan 22 2019 tchvatal@suse.com
- Drop pointless _service file
- Format with spec-cleaner
* Fri Jan 18 2019 josef.moellers@suse.com
- If a system does not have any enclosures, let the daily cron
  script "run_diag_encl"exit gracefully to prevent bogus
  error messages in root's mailbox.
  [bsc#1113097, bsc1113097-run_diag_encl-exit-gracefully.patch]
* Mon Dec 18 2017 jloeser@suse.com
- fix 'diag_encl -d' call (bsc#1072708)
- added patches:
  * ppc64-diag.bug-1072708_create_diag_disk_log_directory.patch
  * ppc64-diag.bug-1072708_create_diag_disk_path.patch
  * ppc64-diag.bug-1072708_fix_service_scripts.patch
  * ppc64-diag.bug-1072708_increase_buffer_for_vpd.patch
  * ppc64-diag.bug-1072708_remove_timestamp.patch
* Fri Oct 20 2017 jloeser@suse.com
- version update to 2.7.4 (fate#322225, fate#326429)
- modified patches:
  * ppc64-diag.varunused.patch
- removed patches:
  * ppc64-diag.opal_errd.patch
  * ppc64-diag.rtas_errd.patch
* Wed Sep  6 2017 jloeser@suse.com
- add missing references for SLE merge:
  * bsc#931001
* Wed Mar  1 2017 jloeser@suse.com
- version update to 2.7.3 (fate#321444)
  - LED support for Marvell HDD
  - Added support to parse new drc-index device tree property
  - ela: remove support on PowerVM LPAR
- modified patches:
  * ppc64-diag.varunused.patch
* Wed Oct 19 2016 jloeser@suse.com
- version update to 2.7.2
  - Added slider enclosure diagnostics support
  - Added support for eSEL parsing
- modified patches:
  * ppc64-diag.opal_errd.patch
* Mon May  9 2016 dvaleev@suse.com
- Update to 2.7.1 (bsc#979032)
  - Fixed endianess issues in diagnostics code
* Tue Mar 22 2016 jloeser@suse.com
- version update to 2.7.0 (FATE#319557)
  - Move from EPL to the GNU GPL license
  - LED support on FSP based PowerNV platform
  - Few minor bugs fixes
- removed patches:
  * ppc64-diag.bug-945385_create_dump_directory_on_startup.patch
  * ppc64-diag.tmpraces.patch
- modified patches:
  * ppc64-diag.opal_errd.patch
  * ppc64-diag.rtas_errd.patch
  * ppc64-diag.varunused.patch
* Wed Sep 16 2015 jloeser@suse.com
- create /var/log/dump directory on startup (bsc#945385)
- added patches:
  * ppc64-diag.bug-945385_create_dump_directory_on_startup.patch
* Thu Jul 23 2015 jloeser@suse.com
- version update to 2.6.9 (FATE#318007)
  - see Changelog under ppc64-diag-2.6.9/ppc64-diag.spec
- modified patches:
  * ppc64-diag.varunused.patch
  * ppc64-diag.rtas_errd.patch
  * ppc64-diag.opal_errd.patch
  * ppc64-diag.tmpraces.patch
- removed patches:
  * ppc64-diag.add_ncurses_include_path.patch
  * ppc64-diag.rtas_errd-LE-fixes-for-extract_platdump.patch
  * ppc64-diag-tmpraces.patch
* Mon Jun  8 2015 dvlaeev@suse.com
- Update to 2.6.8
- Cpu and memory hotplugging support for PowerKVM guest
- Various fixes to opal-dump-parse tool
- Few LE related fixes
- Several security fixes across tools
- Drop upstreamed patches
  ppc64-diag.opal-dump-parse-Add-printk-log-in-the-list-of-dump-s.patch
  ppc64-diag.rtas_errd-Fix-PRRN-Event-handling-on-LE.patch
* Fri Sep 26 2014 stefan.fent@suse.com
- fix bsc #898480 ppc64-diag: fixes for LE support
- patches added:
  - ppc64-diag.opal-dump-parse-Add-printk-log-in-the-list-of-dump-s.patch
  - ppc64-diag.rtas_errd-Fix-PRRN-Event-handling-on-LE.patch
  - ppc64-diag.rtas_errd-LE-fixes-for-extract_platdump.patch
* Tue Sep  9 2014 dvlaeev@suse.com
- Fix download service
* Mon Sep  8 2014 jloeser@suse.com
- version update to 2.6.7 (BNC#894846)
  no upstream changelog provided
- modified patches:
  * ppc64-diag-tmpraces.patch
  * ppc64-diag.add_ncurses_include_path.patch
  * ppc64-diag.opal_errd.patch
  * ppc64-diag.rtas_errd.patch
  * ppc64-diag.varunused.patch
* Tue Jul 22 2014 dvlaeev@suse.com
- Fix download URL once again
* Tue Jul 22 2014 meissner@suse.com
- Also run the systemd %%post snippets within chroots, otherwise
  we will enable the service (as we always install in chroots).
  bnc#882450
- the %%service snippets take argument lists.
* Fri Jul 18 2014 jsegitz@suse.com
- updated ppc64-diag-tmpraces.patch to include proper permissions
  (bnc#882667, CVE-2014-4039)
- added missing pclose and fclose in default path of get_dt_status()
* Mon Jun 23 2014 jloeser@suse.com
- fix /tmp race (BNC#882667, CVE-2014-4038)
- added patches:
  * ppc64-diag-tmpraces.patch
* Fri May 23 2014 dvlaeev@suse.com
- Fix Source url
* Fri May 23 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Fri May  2 2014 jloeser@suse.com
- version update to 2.6.6 (BNC#875775)
  * No upstream changelog provided
  * need to add include/ncurses path for menu.h in lpd/lp_diag.c
- added patches:
  * ppc64-diag.add_ncurses_include_path.patch
* Fri Mar 28 2014 jloeser@suse.com
- remove ppc64.stop_service.patch (already fixed by
  ppc64.opal_errd.patch)
* Tue Mar 25 2014 jloeser@suse.com
- version update to 2.6.4 (BNC#869845)
  new opal error daemon added
  No upstream changelog provided
- add opal_errd.service file
- add ppc64-diag.opal_errd.patch: fix opal_errd init script
- fix rtas_errd init script: $pid to correct pid file
  (init scripts might be obsolete due to systemd)
* Mon Mar 10 2014 jloeser@suse.com
- version update to 2.6.3 (BNC#867346, FATE#315459)
  No upstream changelog provided
* Fri Jan 17 2014 dvlaeev@suse.com
- drop ppc64-diag.unistd.patch
* Fri Jan 10 2014 jloeser@suse.com
- version update to 2.6.2 (FATE#315459)
  - Minor bug fix in diag_encl and encl_led
- drop ppc64-diag.makefile.patch
* Tue Dec 10 2013 dvaleev@suse.com
- enable ppc64le
* Sun Feb 24 2013 dvaleev@suse.com
- Update to 2.6.1:
  * Add Handler to handle PRRN RTAS notification
  * Drop upstreamed ppc64-diag.unistd.patch
  * Update package desription
* Wed Dec 19 2012 dvaleev@suse.com
- update to 2.6.0:
  * Added Light Path Diagnostics code. (moved from powerpc-utils)
  * Introduced new options to diag_encl command (Jim).
  * Added bluehawk enclosure diagnostics support (Jim).
  * Introduced new command "encl_led" to modify identify/fault
    indicators for SCSI enclosures (Jim).
- update ppc64-diag.rtas_errd.patch to not have references to
  /var/lock/subsys
- add ncurses-devel and libvpd2-devel to BuildRequires
* Thu Dec  6 2012 dvaleev@suse.com
- update to 2.5.0
  No upstream changelog provided
- add systemd service for rtas_errd
* Thu Jun 14 2012 cfarrell@suse.com
- license update: EPL-1.0
  SPDX format (http://www.spdx.org/licenses)
* Tue Apr 24 2012 dvaleev@suse.com
- Change upstream Url
- fix build with gcc 4.7
- update to 2.4.3
  - Added message catalogs for the ipr, ixgb, lpfc, and qla2xxx
    drivers
  - Removed obsolete ppc64_diag_servagent script
* Wed Nov  2 2011 dvaleev@suse.com
- update to 2.4.2
  - Minor modifications to GPFS catalog files
    and syslog_to_svclog.cpp
  - Added gpfs files to the catalog, updated ppc64-diag-setup
    notification commands
  - Changed Makefiles and rules.mk to build for the default
    architecture rather than -m32
  - Added ELA code to the package, made changes to the rules.mk
    and minor changes to the spec file
  - Bug fix adding in support for -e and -l, so that root users can
    be notified of serviceable events. Addresses bug #26192
  - Added SIGCHLD handler to clean up servicelog notification
    scripts
  - Removed all absolute path references, specifically
    to /sbin/lsvpd and lsvpd
* Fri Jan 16 2009 olh@suse.de
- fix Supplements string, it cant contain a comma, use * instead
  (bnc#456695)
* Mon Dec  8 2008 olh@suse.de
- do not autoinstall on Cell blades
- add prereq aaa_base to runlevel script in post install
- do not abort on errors
* Fri Dec  5 2008 olh@suse.de
- update Supplements to match only pSeries and Cell blades
* Fri Dec  5 2008 olh@suse.de
- add PreReq libservicelog to get servicelog.db (bnc#417532,bnc#449382)
* Mon Oct 27 2008 olh@suse.de
- use supplements instead of Enhances
* Mon Oct 27 2008 olh@suse.de
- register with servicelog during first install or first boot (bnc#417532)
* Fri Sep 26 2008 olh@suse.de
- add tage Enhances: kernel-ppc64
- make sure package gets selected/installed on a 64bit system
* Wed Sep 10 2008 olh@suse.de
- new ppc64-diag 2.3.1 package (bnc#417532)
